@@ -13,7 +13,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::File::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.213';
+$VERSION = '3.220';
 
 structs('new',
 	'Verilog::Netlist::File::Struct'
@@ -80,6 +80,22 @@ sub new {
     return $parser;
 }
 
+sub contassign {
+    my $self = shift;
+    my $keyword = shift;
+    my $lhs = shift;
+    my $rhs = shift;
+
+    print " ContAssign $keyword $lhs\n" if $Verilog::Netlist::Debug;
+    my $modref = $self->{modref};
+    if (!$modref) {
+	 return $self->error ("CONTASSIGN outside of module definition", $lhs);
+    }
+    $modref->new_contassign
+	 (filename=>$self->filename, lineno=>$self->lineno,
+	  keyword=>$keyword, lhs=>$lhs, rhs=>$rhs);
+}
+
 sub interface {
     my $self = shift;
     my $keyword = shift;
@@ -301,6 +317,7 @@ sub ppinclude {
 
 sub keyword {
     # OVERRIDE Verilog::Parse calls when keyword occurs
+    # Note we use_cb_keyword only if comments are parsed!
     my $self = shift;	# Parser invoked
     $self->SUPER::keyword(@_);
     $self->{_cmtref} = undef;
@@ -319,6 +336,11 @@ sub comment {
     }
 }
 
+# sub operator {   ... Disabled by new(use_cmt_operator => 0)
+# sub number {   ... Disabled by new(use_cmt_number => 0)
+# sub string {   ... Disabled by new(use_cmt_string => 0)
+# sub symbol {   ... Disabled by new(use_cmt_symbol => 0)
+
 sub error {
     my $self = shift;
     my $text = shift;
@@ -366,16 +388,30 @@ sub read {
 				      is_libcell=>$params{is_libcell}||0,
 				      );
 
+    my $keep_cmt = ($params{keep_comments} || $netlist->{keep_comments});
     my $parser = Verilog::Netlist::File::Parser->new
 	( fileref=>$fileref,
 	  filename=>$filepath,	# for ->read
 	  metacomment=>($params{metacomment} || $netlist->{metacomment}),
-	  keep_comments=>($params{keep_comments} || $netlist->{keep_comments}),
+	  keep_comments => $keep_cmt,
+	  use_vars=>($params{use_vars} || $netlist->{use_vars}),
 	  preproc=>($params{preproc} || $netlist->{preproc}),
+	  # Callbacks we need; disable unused for speed
+	  use_cb_attribute => 1,
+	  use_cb_comment => $keep_cmt,
+	  use_cb_keyword => $keep_cmt,
+	  use_cb_number  => 0,
+	  use_cb_operator => 0,
+	  use_cb_string => 0,
+	  use_cb_symbol => 0,
 	  );
     return $fileref;
 }
 
+sub link {
+    # For backward compatibility for SystemC child class, call _link
+    $_[0]->_link(@_);
+}
 sub _link {
 }
 
