@@ -14,7 +14,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Interface::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.213';
+$VERSION = '3.220';
 
 structs('new',
 	'Verilog::Netlist::Interface::Struct'
@@ -174,7 +174,7 @@ sub link {
 
 sub lint {
     my $self = shift;
-    if (!$self->netlist->{skip_pin_interconnect}) {
+    if ($self->netlist->{use_vars}) {
 	foreach my $portref ($self->ports) {
 	    $portref->lint();
 	}
