@@ -11,7 +11,7 @@ use base qw(DynaLoader);
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '3.213';
+$VERSION = '3.220';
 
 ######################################################################
 #### Configuration Section
@@ -21,6 +21,7 @@ bootstrap Verilog::Preproc;
 #In Preproc.xs:
 # sub _new (class, keepcmt, linedir, pedantic)
 # sub _open (class)
+# sub getall (class)
 # sub getline (class)
 # sub eof (class)
 # sub filename (class)
@@ -219,6 +220,11 @@ Returns true at the end of the file.
 Returns the filename of the most recently returned getline().  May not match
 the filename passed on the command line, as `line directives are honored.
 
+=item $self->getall()
+
+Return the entire translated text up to the final EOF, similar to calling
+join('',$self->getline) but significantly faster.  Returns undef at EOF.
+
 =item $self->getline()
 
 Return the next line of text.  Returns undef at EOF.  (Just like
